package com.chenyang.nse.bussiness.entity.vo.mappletxml;

import com.chenyang.nse.bussiness.entity.orm.table.core.mappletxml.TCoreRulEKeyStrInfo;
import com.chenyang.nse.bussiness.entity.orm.table.core.mappletxml.TCoreRulePort;
import com.chenyang.nse.bussiness.entity.orm.table.core.mappletxml.TCoreRuleRandomNumInfo;
import com.chenyang.nse.bussiness.entity.orm.table.core.mappletxml.TCoreRuleRandomStrInfo;
import com.chenyang.nse.bussiness.entity.orm.table.core.mappletxml.TCoreRuleSubstitutionInfo;

public class TCoreRulePortVO {
   private TCoreRulePort tCoreRulePort;
   private TCoreRulEKeyStrInfo tCoreRulEKeyStrInfo;
   private TCoreRuleRandomStrInfo tCoreRuleRandomStrInfo;
   private TCoreRuleSubstitutionInfo tCoreRuleSubstitutionInfo;
   private TCoreRuleRandomNumInfo tCoreRuleRandomNumInfo;

   public TCoreRulePort gettCoreRulePort() {
      return this.tCoreRulePort;
   }

   public void settCoreRulePort(TCoreRulePort tCoreRulePort) {
      this.tCoreRulePort = tCoreRulePort;
   }

   public TCoreRulEKeyStrInfo gettCoreRulEKeyStrInfo() {
      return this.tCoreRulEKeyStrInfo;
   }

   public void settCoreRulEKeyStrInfo(TCoreRulEKeyStrInfo tCoreRulEKeyStrInfo) {
      this.tCoreRulEKeyStrInfo = tCoreRulEKeyStrInfo;
   }

   public TCoreRuleRandomStrInfo gettCoreRuleRandomStrInfo() {
      return this.tCoreRuleRandomStrInfo;
   }

   public void settCoreRuleRandomStrInfo(TCoreRuleRandomStrInfo tCoreRuleRandomStrInfo) {
      this.tCoreRuleRandomStrInfo = tCoreRuleRandomStrInfo;
   }

   public TCoreRuleSubstitutionInfo gettCoreRuleSubstitutionInfo() {
      return this.tCoreRuleSubstitutionInfo;
   }

   public void settCoreRuleSubstitutionInfo(TCoreRuleSubstitutionInfo tCoreRuleSubstitutionInfo) {
      this.tCoreRuleSubstitutionInfo = tCoreRuleSubstitutionInfo;
   }

   public TCoreRuleRandomNumInfo gettCoreRuleRandomNumInfo() {
      return this.tCoreRuleRandomNumInfo;
   }

   public void settCoreRuleRandomNumInfo(TCoreRuleRandomNumInfo tCoreRuleRandomNumInfo) {
      this.tCoreRuleRandomNumInfo = tCoreRuleRandomNumInfo;
   }
}
